==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/modules/MailMerge/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_STEP_1' => 'Step 1: Select Module and Template',
  'LBL_MAILMERGE_MODULE' => 'Select Module: ',
  'LBL_MAILMERGE_SELECTED_MODULE' => 'Selected Module: ',
  'LBL_MAILMERGE_TEMPLATES' => 'Select Template: ',
  'LBL_STEP_2' => 'Step 2: Select Objects to Merge',
  'LBL_MAILMERGE_OBJECTS' => 'Select Objects: ',
  'LBL_STEP_3' => 'Set Contact Association',
  'LBL_STEP_4' => 'Review and Complete',
  'LBL_SELECTED_MODULE' => 'Selected Module: ',
  'LBL_SELECTED_TEMPLATE' => 'Selected Template: ',
  'LBL_SELECTED_ITEMS' => 'Selected Items: ',
  'LBL_STEP_5' => 'Mail Merge Complete',
  'LBL_MERGED_FILE' => 'Merged File: ',
  'LNK_NEW_MAILMERGE' => 'Begin Mail Merge',
  'LNK_UPLOAD_TEMPLATE' => 'Upload Template',
  'LBL_DOC_NAME' => 'Document Name:',
  'LBL_FILENAME' => 'File Name:',
  'LBL_DOC_VERSION' => 'Revision:',
  'LBL_DOC_DESCRIPTION'=>'Description:',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_RELATIONSHIP' => 'Set Contact Relationship',
  'LBL_FINISH' => 'Begin Merge',
  'LBL_NEXT' => 'Next >',
  'LBL_BACK' => '< Back',
  'LBL_START' => 'Click Here to Continue',
  'LBL_TEMPLATE_NOTICE' => 'Templates are Microsoft Word documents containing merge fields that have been uploaded and stored in the Documents module.',
  'LBL_CONTAINS_CONTACT_INFO' => 'Selected template contains related ',
  'LBL_ADDIN_NOTICE' => 'This requires the installation of Sugar Mail Merge add-in to Microsoft Word.',
  'LBL_BROWSER_NOTICE' => 'You must be running IE 6.0 or greater to perform the actual merge.',
);


?>

==> SugarCE-6.5.26.zip: SugarCE-Full-6.5.26/modules/MailMerge/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2013 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_STEP_1' => 'Step 1: Select Module and Template',
  'LBL_MAILMERGE_MODULE' => 'Select Module: ',
  'LBL_MAILMERGE_SELECTED_MODULE' => 'Selected Module: ',
  'LBL_MAILMERGE_TEMPLATES' => 'Select Template: ',
  'LBL_STEP_2' => 'Step 2: Select Objects to Merge',
  'LBL_MAILMERGE_OBJECTS' => 'Select Objects: ',
  'LBL_STEP_3' => 'Set Contact Association',
  'LBL_STEP_4' => 'Review and Complete',
  'LBL_SELECTED_MODULE' => 'Selected Module: ',
  'LBL_SELECTED_TEMPLATE' => 'Selected Template: ',
  'LBL_SELECTED_ITEMS' => 'Selected Items: ',
  'LBL_STEP_5' => 'Mail Merge Complete',
  'LBL_MERGED_FILE' => 'Merged File: ',
  'LNK_NEW_MAILMERGE' => 'Begin Mail Merge',
  'LNK_UPLOAD_TEMPLATE' => 'Upload Template',
  'LBL_DOC_NAME' => 'Document Name:',
  'LBL_FILENAME' => 'File Name:',
  'LBL_DOC_VERSION' => 'Revision:',
  'LBL_DOC_DESCRIPTION'=>'Description:',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_RELATIONSHIP' => 'Set Contact Relationship',
  'LBL_FINISH' => 'Begin Merge',
  'LBL_NEXT' => 'Next >',
  'LBL_BACK' => '< Back',
  'LBL_START' => 'Click Here to Continue',
  'LBL_TEMPLATE_NOTICE' => 'Templates are Microsoft Word documents containing merge fields that have been uploaded and stored in the Documents module.',
  'LBL_CONTAINS_CONTACT_INFO' => 'Selected template contains related ',
  'LBL_ADDIN_NOTICE' => 'This requires the installation of Sugar Mail Merge add-in to Microsoft Word.',
  'LBL_BROWSER_NOTICE' => 'You must be running IE 6.0 or greater to perform the actual merge.',
  'LBL_REMOVE' => 'Remove Item(s)' /*for 508 compliance fix*/,
  'LBL_ADD' => 'Add Item(s)' /*for 508 compliance fix*/,
  'LBL_BROWSER_REQUIREMENT' => 'This requires IE 6.0 or greater for Windows.',
  'LBL_FORM_SELECT_TEMPLATE' => 'Please select a template.',
  'LBL_SELECT_ONE' => 'Please select at least one item.',
  'LBL_AVAILABLE' => 'Available',
  'LBL_SELECTED' => 'Selected',
  'LBL_RELATED_INFO_SELECTION' => 'Use the selections below to identify the related information you would like to display in your merged document. Skip this step if your template document contains no related information.',

);


?>
